@@ -1,7 +1,7 @@
 /* -*- c-basic-offset: 2 -*- */
 /*
   Copyright(C) 2009-2018 Brazil
-  Copyright(C) 2018-2019 Kouhei Sutou <kou@clear-code.com>
+  Copyright(C) 2018-2020 Sutou Kouhei <kou@clear-code.com>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -1989,6 +1989,18 @@ grn_fileinfo_close(grn_ctx *ctx, fileinfo *fi)
     fi->fmo = NULL;
   }
   if (fi->fh != INVALID_HANDLE_VALUE) {
+    if (grn_logger_pass(ctx, GRN_LOG_DEBUG)) {
+      TCHAR path[MAX_PATH];
+      DWORD path_length_including_null =
+        GetFinalPathNameByHandleA(fi->fh,
+                                  &path,
+                                  MAX_PATH,
+                                  0);
+      if (path_length_including_null != 0 &&
+          path_length_including_null <= MAX_PATH) {
+        GRN_LOG(ctx, GRN_LOG_DEBUG, "[io][close] <%s>", path);
+      }
+    }
     CloseHandle(fi->fh);
     CRITICAL_SECTION_FIN(fi->cs);
     fi->fh = INVALID_HANDLE_VALUE;
@@ -2116,6 +2128,7 @@ grn_fileinfo_open(grn_ctx *ctx, fileinfo *fi, const char *path, int flags)
   }
   fi->dev = st.st_dev;
   fi->inode = st.st_ino;
+  GRN_LOG(ctx, GRN_LOG_DUMP, "[io][open] <%s>", path);
   return GRN_SUCCESS;
 }
 
@@ -2135,11 +2148,27 @@ grn_inline static grn_rc
 grn_fileinfo_close(grn_ctx *ctx, fileinfo *fi)
 {
   if (fi->fd != -1) {
+    char path[PATH_MAX];
+    path[0] = '\0';
+    if (grn_logger_pass(ctx, GRN_LOG_DUMP)) {
+      /* TODO: This works only on Linux. We need to use more portable way. */
+      char proc_path[PATH_MAX];
+      grn_snprintf(proc_path, PATH_MAX, PATH_MAX, "/proc/self/fd/%d", fi->fd);
+      ssize_t path_size = readlink(proc_path, path, PATH_MAX);
+      if (path_size == -1) {
+        errno = 0;
+      } else {
+        path[path_size] = '\0';
+      }
+    }
     if (grn_close(fi->fd) == -1) {
       SERR("close");
       return ctx->rc;
     }
     fi->fd = -1;
+    if (path[0]) {
+      GRN_LOG(ctx, GRN_LOG_DUMP, "[io][close] <%s>", path);
+    }
   }
   return GRN_SUCCESS;
 }
