@@ -515,6 +515,9 @@ grn_column_inspect_common(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
     GRN_TEXT_PUTS(ctx, buf, " range:");
     if (range) {
       grn_inspect_name(ctx, buf, range);
+      if (grn_enable_reference_count) {
+        grn_obj_unlink(ctx, range);
+      }
     } else {
       grn_text_lltoa(ctx, buf, range_id);
     }
@@ -605,6 +608,9 @@ grn_ii_inspect(grn_ctx *ctx, grn_obj *buf, grn_obj *obj)
     source = grn_ctx_at(ctx, source_id);
     if (source) {
       grn_inspect_name(ctx, buf, source);
+      if (grn_enable_reference_count) {
+        grn_obj_unlink(ctx, source);
+      }
     } else {
       grn_text_lltoa(ctx, buf, source_id);
     }
