@@ -1,4 +1,4 @@
-# Copyright(C) 2014-2019  Sutou Kouhei <kou@clear-code.com>
+# Copyright(C) 2014-2020  Sutou Kouhei <kou@clear-code.com>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -16,8 +16,6 @@
 
 require "pathname"
 
-require_relative "../vendor/apache-arrow-source/dev/tasks/linux-packages/package-task"
-
 module LaunchpadHelper
   private
   def enable_ubuntu?
@@ -37,8 +35,8 @@ module LaunchpadHelper
     [
       ["xenial", "16.04"],
       ["bionic", "18.04"],
-      ["disco", "19.04"],
       ["eoan", "19.10"],
+      ["focal", "20.04"],
     ]
   end
 
@@ -107,7 +105,8 @@ allow_unsigned_uploads = 0
          "#{@package}_#{@deb_upstream_version}.orig.tar.gz")
       cd(deb_archive_base_name) do
         cp_r(absolute_debian_dir, "debian")
-        version_suffix = "ubuntu#{version}.1"
+        minor_version = ENV["UBUNTU_MINOR_VERSION"] || "1"
+        version_suffix = "ubuntu#{version}.#{minor_version}"
         deb_version = "#{detect_current_deb_version}.#{version_suffix}"
         sh("dch",
            "--distribution", code_name,
